package edu.nyu.sps.speech;

import android.content.ActivityNotFoundException;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.content.pm.PackageManager;
import android.content.pm.ResolveInfo;
import android.os.Bundle;
import android.speech.RecognizerIntent;
import android.support.v7.app.AppCompatActivity;
import android.widget.TextView;
import android.widget.Toast;

import java.util.ArrayList;
import java.util.List;

public class MainActivity extends AppCompatActivity {
    private static final int RECOGNIZE_SPEECH_REQUEST_CODE = 1;
    private TextView textView;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        textView = (TextView)findViewById(R.id.textView);

        //Does this device have any Activities that recognize speech?
        PackageManager packageManager = getPackageManager();
        Intent intent = new Intent(RecognizerIntent.ACTION_RECOGNIZE_SPEECH);
        List<ResolveInfo> activities = packageManager.queryIntentActivities(intent, 0);

        for (int i = 0; i < activities.size(); ++i) {
            final ResolveInfo resolveInfo = activities.get(i);
            final ActivityInfo activityInfo = resolveInfo.activityInfo;
            textView.append(activityInfo.loadLabel(packageManager) + "\n");
        }

        //The first putExtra is required.  The others are optional.
        intent.putExtra(
                RecognizerIntent.EXTRA_LANGUAGE_MODEL,
                RecognizerIntent.LANGUAGE_MODEL_FREE_FORM
        );
        intent.putExtra(RecognizerIntent.EXTRA_PROMPT, "Speak in English");
        intent.putExtra(RecognizerIntent.EXTRA_LANGUAGE, "en-US");
        intent.putExtra(RecognizerIntent.EXTRA_MAX_RESULTS, 3);

        try {
            startActivityForResult(intent, RECOGNIZE_SPEECH_REQUEST_CODE);
        }
        catch (ActivityNotFoundException exception) {
            textView.append(exception.toString());
        }
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode != RECOGNIZE_SPEECH_REQUEST_CODE) {
            Toast.makeText(this, "requestCode = " + requestCode, Toast.LENGTH_LONG).show();
            return;
        }

        if (resultCode != RESULT_OK) {
            Toast.makeText(this, "resultCode = " + resultCode, Toast.LENGTH_LONG).show();
            return;
        }

        ArrayList<String> list = data.getStringArrayListExtra(RecognizerIntent.EXTRA_RESULTS);
        for (int i = 0; i < list.size(); ++i) {
            textView.append(i + 1 + " " + list.get(i) + "\n");
        }
        textView.append("\n");
    }
}
